@@ -26,8 +26,27 @@ class StorageMessage:
     default: TranslatedText
     default_plural: TranslatedText
     context: str
+    has_plural: bool
     translations: Mapping[Locale, StorageTranslation]
 
+    @property
+    def number_of_non_default_attributes(self) -> int:
+        number_of_non_default_attributes = 1
+
+        if self.default != self.id:
+            number_of_non_default_attributes += 1
+
+        if self.default_plural != self.default:
+            number_of_non_default_attributes += 1
+
+        if self.context:
+            number_of_non_default_attributes += 1
+
+        if self.has_plural:
+            number_of_non_default_attributes += 1
+
+        return number_of_non_default_attributes
+
 
 @dataclass(slots=True)
 class StorageTranslation:
@@ -75,5 +94,6 @@ class BaseStorage(IStorage, ABC):
                 default=message.default or message.id,
                 default_plural=message.default_plural or message.id,
                 context=str(message.context) if message.context else "",
+                has_plural="n" in message.extra,
                 translations={},
             )
